==> libgda-0.8.190.tar.bz2: libgda-0.8.190/libgda/gda-client.h <==
/* GDA library
 * Copyright (C) 1998-2002 The GNOME Foundation.
 *
 * AUTHORS:
 *      Michael Lausch <michael@lausch.at>
 *	Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gda_client_h__)
#  define __gda_client_h__

#include <libgda/gda-connection.h>

G_BEGIN_DECLS

#define GDA_TYPE_CLIENT            (gda_client_get_type())
#define GDA_CLIENT(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GDA_TYPE_CLIENT, GdaClient))
#define GDA_CLIENT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GDA_TYPE_CLIENT, GdaClientClass))
#define GDA_IS_CLIENT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE(obj, GDA_TYPE_CLIENT))
#define GDA_IS_CLIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), GDA_TYPE_CLIENT))

typedef struct _GdaClientClass   GdaClientClass;
typedef struct _GdaClientPrivate GdaClientPrivate;

struct _GdaClient {
	GObject object;
	GdaClientPrivate *priv;
};

struct _GdaClientClass {
	GObjectClass parent_class;

	/* signals */
	void (* error) (GdaClient *client, GdaConnection *cnc, GList *error_list);
	//void (* action_notified) (GdaClient *client,
	//			  GdaActionId action,
	//			  GdaParameterList *params);
};

GType          gda_client_get_type (void);
GdaClient     *gda_client_new (void);

GdaConnection *gda_client_open_connection (GdaClient *client,
					   const gchar *dsn,
					   const gchar *username,
					   const gchar *password);
const GList   *gda_client_get_connection_list (GdaClient *client);
GdaConnection *gda_client_find_connection (GdaClient *client,
					   const gchar *dsn,
					   const gchar *username,
					   const gchar *password);
void           gda_client_close_all_connections (GdaClient *client);

G_END_DECLS

#endif

==> libgda-0.8.191.tar.bz2: libgda-0.8.191/libgda/gda-client.h <==
/* GDA library
 * Copyright (C) 1998-2002 The GNOME Foundation.
 *
 * AUTHORS:
 *      Michael Lausch <michael@lausch.at>
 *	Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gda_client_h__)
#  define __gda_client_h__

#include <libgda/gda-connection.h>

G_BEGIN_DECLS

#define GDA_TYPE_CLIENT            (gda_client_get_type())
#define GDA_CLIENT(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GDA_TYPE_CLIENT, GdaClient))
#define GDA_CLIENT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GDA_TYPE_CLIENT, GdaClientClass))
#define GDA_IS_CLIENT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE(obj, GDA_TYPE_CLIENT))
#define GDA_IS_CLIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), GDA_TYPE_CLIENT))

typedef struct _GdaClientClass   GdaClientClass;
typedef struct _GdaClientPrivate GdaClientPrivate;

struct _GdaClient {
	GObject object;
	GdaClientPrivate *priv;
};

struct _GdaClientClass {
	GObjectClass parent_class;

	/* signals */
	void (* error) (GdaClient *client, GdaConnection *cnc, GList *error_list);
	//void (* action_notified) (GdaClient *client,
	//			  GdaActionId action,
	//			  GdaParameterList *params);
};

GType          gda_client_get_type (void);
GdaClient     *gda_client_new (void);

GdaConnection *gda_client_open_connection (GdaClient *client,
					   const gchar *dsn,
					   const gchar *username,
					   const gchar *password);
GdaConnection *gda_client_open_connection_from_string (GdaClient *client,
						       const gchar *provider_id,
						       const gchar *cnc_string);
const GList   *gda_client_get_connection_list (GdaClient *client);
GdaConnection *gda_client_find_connection (GdaClient *client,
					   const gchar *dsn,
					   const gchar *username,
					   const gchar *password);
void           gda_client_close_all_connections (GdaClient *client);

G_END_DECLS

#endif
